==> mupad-1.4.2.tgz: mupad/share/mmg/include/kernel/MGH_message.h <==
/******************************************************************************/
/* DATEI:       MGH_message.h                                                 */
/* AUTOR:       ?                                                             */
/* ERSTELLT:    20/07/95                                                      */
/* GEAENDERT:   20/07/95                                                      */
/* INHALT:      Definitionen, Makros, Prototypen zur Kommunikation            */
/******************************************************************************/

#ifndef __MGH_messages__
#define __MGH_messages__


#ifdef DOS_FILENAMES
#  include "MPR_prot.h"
#else
#  include "MPR_protocol.h"
#endif


/*** Definements **************************************************/

#define MGHCempty	""


/*** Makros *******************************************************/

#define MGH_eval(t,s) MGH_JumpTab[(int) t](t,s)


/*** Variablen ****************************************************/
#ifdef MSDOS

extern MPRTchannel Send_to_xmupad, Send_to_vcam;

#else

/*
 * Communication channels to/from xmupad
 */
extern MPRTchannel Send_to_xmupad, Recv_from_xmupad;

/*
 * Message buffer
 */
extern S_Pointer   MGH_message_buffer;
extern int         MGH_index, MGH_buffer_length;

/*
 * Jump table for evaluation of messages
 */
extern long        MDBV_debug_activ;
extern void      (*MGH_JumpTab[MPRCno_of_messages])(MPRTtype type, char *s);

#endif /* MSDOS */

/*** Prototypen der Funktionen ************************************/

#ifdef MSDOS

#  define MGH_init()
#  define MGH_exit()
#  define MGH_write(s, c, t) MPR_putmessage(c, t, s)

#else

void       MGH_communication_error ( MPRTtype type, char *s );

void       MGH_init                ();
void       MGH_exit                ();
void       MGH_input               ( MPRTtype type, char *s );
void       MGH_output              ( MPRTtype type, char *s );
void       MGH_system              ( MPRTtype type, char *s );
void       MGH_gettextinput        ( MPRTtype type, char *s );
void       MGH_getinput            ( MPRTtype type, char *s );
void       MGH_help                ( MPRTtype type, char *s );
void       MGH_error               ( MPRTtype type, char *s );
void       MGH_example             ( MPRTtype type, char *s );
void       MGH_mdxcommand          ( MPRTtype type, char *s );
void       MGH_displayvariables    ( MPRTtype type, char *s );
void       MGH_prompt              ( MPRTtype type, char *s );
void       MGH_longprompt          ( MPRTtype type, char *s );
void       MGH_textinputanswer     ( MPRTtype type, char *s );
void       MGH_inputanswer         ( MPRTtype type, char *s );
void       MGH_stop                ( MPRTtype type, char *s );
void       MGH_quit                ( MPRTtype type, char *s );
void       MGH_connect             ( MPRTtype type, char *s );

int        MGH_write               ( char *s, MPRTchannel iop, MPRTtype type );
S_Pointer  MGH_read                ( MPRTtype *type, MPRTchannel iop );

void       MGH_send_prompt         ();
void       MGH_send_lprompt        ();
void       MGH_wait                ();

#endif /* MSDOS */

void       MGH_getstatus           ( MPRTtype type, char *s );
void       MGH_textwidth           ( MPRTtype type, char *s );
void       MGH_prettyprint         ( MPRTtype type, char *s );
void       MGH_debuggermode        ( MPRTtype type, char *s );

void       MGH_vm_plot_cmd         ( MPRTtype type, char *s );

#endif /* __MGH_messages__ */

==> mupad-2.0.0.tgz: mupad/share/mmg/include/kernel/MGH_message.h <==
/******************************************************************************/
/* DATEI:       MGH_message.h                                                 */
/* AUTOR:       ?                                                             */
/* ERSTELLT:    20/07/95                                                      */
/* GEAENDERT:   20/07/95                                                      */
/* INHALT:      Definitionen, Makros, Prototypen zur Kommunikation            */
/******************************************************************************/

#ifndef __MGH_messages__
#define __MGH_messages__


#ifdef DOS_FILENAMES
#  include "MPR_prot.h"
#else
#  include "MPR_protocol.h"
#endif

#include "MUP_env.h"

/* Definements **************************************************/

#define MGHCempty	""


/* Makros *******************************************************/

#define MGH_eval(t,s)  if (t >= MPRCno_of_messages) \
                         MGH_communication_error(t,s);        \
                       else   MGH_JumpTab[(int) t](t,s);


/* Variablen ****************************************************/
#ifdef MSDOS

extern MPRTchannel Send_to_xmupad, Send_to_vcam;

#else

/*
 * Communication channels to/from xmupad
 */
extern MPRTchannel Send_to_xmupad, Recv_from_xmupad;

/*
 * Message buffer
 */
extern S_Pointer   MGH_message_buffer;
extern int         MGH_index, MGH_buffer_length;

/*
 * Jump table for evaluation of messages
 */
extern void      (*MGH_JumpTab[MPRCno_of_messages])(MPRTtype type, char *s);

#endif /* MSDOS */

/* Prototypen der Funktionen ************************************/

#ifdef MSDOS

#  define MGH_init()
#  define MGH_exit()
#  define MGH_write(s, c, t) MPR_putmessage(c, t, s)

#else

void       MGH_communication_error ( MPRTtype type, char *s );

void       MGH_init                ();
void       MGH_exit                ();

void       MGH_textinputanswer     ( MPRTtype type, char *s );
void       MGH_inputanswer         ( MPRTtype type, char *s );
void       MGH_quit                ( MPRTtype type, char *s );

int        MGH_write               ( const char *s, MPRTchannel iop, MPRTtype type );
S_Pointer  MGH_read                ( MPRTtype *type, MPRTchannel iop );

void       MGH_send_prompt         ();
void       MGH_send_lprompt        ();
void       MGH_wait                ();

#endif /* MSDOS */

void       MGH_getstatus           ( MPRTtype type, const char *s );
void       MGH_textwidth           ( MPRTtype type, const char *s );
void       MGH_prettyprint         ( MPRTtype type, const char *s );
void       MGH_debuggermode        ( MPRTtype type, const char *s );
void       MGH_vm_plot_cmd         ( MPRTtype type, const char *s );
void       MGH_compl_request       ( MPRTtype type, char *s );

#endif /* __MGH_messages__ */
